==> tutti-ui-swing-1.4.1-sources.jar: fr/ifremer/tutti/ui/swing/content/AbstractChangeLocaleAction.java <==
package fr.ifremer.tutti.ui.swing.content;

/*
 * #%L
 * Tutti :: UI
 * $Id: AbstractChangeLocaleAction.java 587 2013-03-12 13:18:01Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.4.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/AbstractChangeLocaleAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import java.util.Locale;

/**
 * TODO
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0.3
 */
public abstract class AbstractChangeLocaleAction extends AbstractChangeScreenAction {


    protected AbstractChangeLocaleAction(MainUIHandler handler) {
        super(handler, true, null);
    }

    protected abstract Locale getLocale();

    @Override
    protected void doAction() throws Exception {

        getHandler().changeLocale(getLocale());
    }
}

==> tutti-ui-swing-2.0-sources.jar: fr/ifremer/tutti/ui/swing/content/AbstractChangeLocaleAction.java <==
package fr.ifremer.tutti.ui.swing.content;

/*
 * #%L
 * Tutti :: UI
 * $Id: AbstractChangeLocaleAction.java 587 2013-03-12 13:18:01Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.0/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/AbstractChangeLocaleAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import java.util.Locale;

/**
 * TODO
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0.3
 */
public abstract class AbstractChangeLocaleAction extends AbstractChangeScreenAction {


    protected AbstractChangeLocaleAction(MainUIHandler handler) {
        super(handler, true, null);
    }

    protected abstract Locale getLocale();

    @Override
    protected void doAction() throws Exception {

        getHandler().changeLocale(getLocale());
    }
}
